#!/usr/bin/env python

#
# Usage: python gen-images.py SRC_FILE_NAME_TMPL DST_FILE_NAME_TMPL COUNT
#          DELAY TO_DISK_LAG IMAGE_PATH_PV
#
#   SRC_FILE_NAME_TMPL  source file name template
#   DST_FILE_NAME_TMPL  destination file name template
#   COUNT               how many images to collect
#   DELAY               time to wait in seconds between each collected image
#   TO_DISK_LAG         image N - TO_DISK_LAG is written to disk when image N
#                       is collected
#   IMAGE_PATH_PV       put the full path of the collected image here
#
# Example:
# $ ls -1
# sim-data
# image_0001.cbf
# image_0002.cbf
# $ python gen-images.py \
#     image.cbf sim-data/image.cbf 10 1.0 1 x7idb:Is:ImageFilePath
#

import os
import shutil
import subprocess
import sys
import time

def main(args):
  (srcFileNameTmpl, dstFileNameTmpl, count, delay, toDiskLag, imagePathPv) = \
    parseCmdLineArgs(args)
  nullFile = open(os.devnull, "w")
  srcNum = 1
  for dstNum in xrange(1, count + 1 + toDiskLag):
    if dstNum > 1:
      print "  Sleeping %.3f seconds" % delay
      time.sleep(delay)
    if dstNum <= count:
      dstFileName = createFileName(dstFileNameTmpl, dstNum)
      print "Collecting %s" % dstFileName
      retcode = subprocess.call(["caput", "-S", imagePathPv, dstFileName],
        stdout=nullFile)
      if retcode != 0:
        raise Exception("subprocess failed: caput -S \"%s\" \"%s\"" % \
          (imagePathPv, dstFileName))
    if dstNum - toDiskLag > 0:
      dstFileName = createFileName(dstFileNameTmpl, dstNum - toDiskLag)
      srcFileName = createFileName(srcFileNameTmpl, srcNum)
      if not os.path.exists(srcFileName):
        srcNum = 1
        srcFileName = createFileName(srcFileNameTmpl, srcNum)
        if not os.path.exists(srcFileName):
          raise Exception("Source file does not exist: %s" % srcFileName)
      print "  Creating %s" % dstFileName
      shutil.copy(srcFileName, dstFileName)
      srcNum += 1

def parseCmdLineArgs(args):
  return (args[1], args[2], int(args[3]), float(args[4]), int(args[5]),
    args[6])

def createFileName(fileNameTmpl, num, minNumWidth=4):
  dotIndex = fileNameTmpl.rindex(".")
  return "%s_%0*d%s" % \
    (fileNameTmpl[:dotIndex], minNumWidth, num, fileNameTmpl[dotIndex:])

if __name__ == "__main__": main(sys.argv)
